[chronojump] spinbutton_sprint_export_image_width/height related to preferences and fs, re widgets
- From: Xavier de Blas <xaviblas src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [chronojump] spinbutton_sprint_export_image_width/height related to preferences and fs, re widgets
- Date: Mon, 15 Mar 2021 18:28:16 +0000 (UTC)
commit 9100a116955efcf9b3f6b31cdea1f0a8ed2e858b
Author: Xavier de Blas <xaviblas gmail com>
Date: Mon Mar 15 19:27:52 2021 +0100
spinbutton_sprint_export_image_width/height related to preferences and fs,re widgets
src/gui/app1/chronojump.cs | 6 ++++++
src/gui/app1/forceSensorAnalyze.cs | 6 +++++-
src/gui/app1/runEncoderAnalyze.cs | 6 +++++-
3 files changed, 16 insertions(+), 2 deletions(-)
---
diff --git a/src/gui/app1/chronojump.cs b/src/gui/app1/chronojump.cs
index 91621e10..3ec4c620 100644
--- a/src/gui/app1/chronojump.cs
+++ b/src/gui/app1/chronojump.cs
@@ -675,6 +675,12 @@ public partial class ChronoJumpWindow
threshold = new Threshold();
cp2016 = new Chronopic2016();
+ // ------ Creating sprint widgets ------
+
+ spinbutton_sprint_export_image_width.Value = preferences.exportGraphWidth;
+ spinbutton_sprint_export_image_height.Value = preferences.exportGraphHeight;
+
+
// ------ Creating encoder widgets ------
if(splashWin != null)
diff --git a/src/gui/app1/forceSensorAnalyze.cs b/src/gui/app1/forceSensorAnalyze.cs
index 195ef97f..d6009102 100644
--- a/src/gui/app1/forceSensorAnalyze.cs
+++ b/src/gui/app1/forceSensorAnalyze.cs
@@ -764,10 +764,14 @@ public partial class ChronoJumpWindow
preferences.exportGraphHeight,
Convert.ToInt32(spinbutton_force_sensor_export_image_height.Value));
Sqlite.Close();
- //change also spinbuttons of export runEncoder
+ //change also spinbuttons of export sprint and runEncoder
+ spinbutton_sprint_export_image_width.Value = spinbutton_force_sensor_export_image_width.Value;
+ spinbutton_sprint_export_image_height.Value =
spinbutton_force_sensor_export_image_height.Value;
+
spinbutton_run_encoder_export_image_width.Value =
spinbutton_force_sensor_export_image_width.Value;
spinbutton_run_encoder_export_image_height.Value =
spinbutton_force_sensor_export_image_height.Value;
+
forceSensorExport = new ForceSensorExport (
notebook_force_sensor_export,
progressbar_force_sensor_export,
diff --git a/src/gui/app1/runEncoderAnalyze.cs b/src/gui/app1/runEncoderAnalyze.cs
index 5f8f44ee..72df29d1 100644
--- a/src/gui/app1/runEncoderAnalyze.cs
+++ b/src/gui/app1/runEncoderAnalyze.cs
@@ -334,10 +334,14 @@ public partial class ChronoJumpWindow
preferences.exportGraphHeight,
Convert.ToInt32(spinbutton_run_encoder_export_image_height.Value));
Sqlite.Close();
- //change also spinbuttons of export forceSensor
+ //change also spinbuttons of export sprint and forceSensor
+ spinbutton_sprint_export_image_width.Value = spinbutton_run_encoder_export_image_width.Value;
+ spinbutton_sprint_export_image_height.Value =
spinbutton_run_encoder_export_image_height.Value;
+
spinbutton_force_sensor_export_image_width.Value =
spinbutton_run_encoder_export_image_width.Value;
spinbutton_force_sensor_export_image_height.Value =
spinbutton_run_encoder_export_image_height.Value;
+
runEncoderExport = new RunEncoderExport (
notebook_run_encoder_export,
progressbar_run_encoder_export,
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]